| Title: | CoCoSo - Combined Compromise Solution Method for MCDA |
|---|---|
| Description: | Provides a set of functions to implement the Combined Compromise Solution (CoCoSo) Method created by Yazdani, Zarate, Zavadskas and Turskis (2019) <doi:10.1108/MD-05-2017-0458>. This method is based on an integrated simple additive weighting and compromise exponentially weighted product model. |
| Authors: | Sergio Floquet [aut, cre] (ORCID: <https://orcid.org/0000-0002-7998-350X>), Marcos Santos [aut] (ORCID: <https://orcid.org/0000-0003-1533-5535>) |
| Maintainer: | Sergio Floquet <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.1.0 |
| Built: | 2026-05-14 06:33:52 UTC |
| Source: | https://github.com/sergiofloquet/cocosor |
Verify if the dataset to be submitted to cocoso function is correctly formatted.
check_input_data_cocoso(md_data)check_input_data_cocoso(md_data)
md_data |
Must be a data frame with information about Criteria, Alternatives and Optimal Value. See example_cocoso. |
True if the dataset is correctly formatted and False otherwise.
data(example_cocoso) check_input_data_cocoso(example_cocoso)data(example_cocoso) check_input_data_cocoso(example_cocoso)
Implementation of CoCoSo Method
cocoso(md_data, parameter_alpha = 0.5)cocoso(md_data, parameter_alpha = 0.5)
md_data |
Must be a data frame with information about Criteria, Alternatives and Optimal Value. See example_cocoso. |
parameter_alpha |
Parameter for third aggregation strategies. |
Final ranking of all alternatives from CoCoSo method. In addition, we compute and present all three aggregation strategies.
data(example_cocoso) cocoso(example_cocoso)data(example_cocoso) cocoso(example_cocoso)
Information of decision-making matrix from a logistic provider selection problem including information about criteria, alternatives and weights.
example_cocosoexample_cocoso
A data frame with 10 rows and 6 columns.
Extract in "A combined compromise solution (CoCoSo) method for multi-criteria decision-making problems", Yazdani, M., Zarate, P., Kazimieras Zavadskas, E., & Turskis, Z. (2019).
example_cocosoexample_cocoso
Padronization of decision-making matriz by sum.
standard_cocoso(md_data)standard_cocoso(md_data)
md_data |
Decision-making matrix. |
A Decision-making matrix normalize.
standard_cocoso(mtcars)standard_cocoso(mtcars)